---
title: "Everyone makes decisions in their own interests"
description: "Theory: everyone makes decisions in that moment based on their own belief of personal gain, whether it's truly for their benefit or not. People never choose to do things which they do not receive some sort of benefit from choosing to do."
pubDate: 'Mar 03 2025'
# heroImage: '/blog-placeholder-3.jpg'
---

Update May 16, 2025: Turns out that this is a centuries-old philosophical debate: https://en.wikipedia.org/wiki/Psychological_egoism

---

Theory: everyone makes decisions in that moment based on their own belief of personal gain, whether it's truly for their benefit or not. People never choose to do things which they do not receive some sort of benefit from choosing to do.

Essentially, every action seems to stem from a calculation—whether conscious or subconscious—that it serves some form of personal interest, even if that interest isn't always immediately obvious.

There are some general observable guidelines that form the basis of this theory:

1. People assess the "worth" of an action based on the benefits they expect to receive, whether those benefits are physical pleasure, emotional relief, social approval, or alignment with personal values. What counts as "benefit" can vary widely from person to person.
2. While long-term outcomes are considered, many decisions are heavily influenced by immediate rewards. For example, a drug user might choose to take drugs because the immediate euphoria or escape they provide is compelling—even if, in the long run, these actions cause harm to their relationships or themselves.
3. Our brains are wired to seek pleasure and avoid pain. Even when someone makes a decision that appears self-destructive, it's often because their internal reward circuitry has prioritized a short-term benefit over potential long-term costs.
4. "Self-interest" doesn't always mean purely selfish or hedonistic choices. Sometimes, actions like donating to charity or following a strict ethical code are done because they provide a sense of fulfillment, social belonging, or alignment with one's identity. In this broader view, even altruistic actions serve personal interests.
5. Decisions aren't just about weighing benefits and drawbacks in a straightforward way. Emotions, biases, social pressures, and even habits can alter how we perceive what's "worth it" at any given moment.

Every decision goes through a kind of personal cost-benefit analysis.

From the journal Frontiers in Ecology and Evolution:

> In these modeling approaches, the researcher deduces the predicted decision by maximizing a metric of evolutionary fitness. Already Alfred Lotka hinted that there are mechanisms within a body that enable the organism to make evolutionarily good decisions: “What guides a human being, for example in the selection of his activities, are his tastes, his desires, his pleasures and pains, actual or prospective” (Lotka, 1925, p. 352). He pointed at an evolved neurological basis—and an ability to predict—that controls decisions. ([Source](https://www.frontiersin.org/journals/ecology-and-evolution/articles/10.3389/fevo.2019.00164/full#:~:text=In%20these%20modelingthat%20controls%20decisions.))

The article also includes many examples of animals that exhibit this selfish subconscious decision making, including unicellular organisms which evaluate conditions inside the cell and the surroundings, pursue resources, close enemies out, divide, or enter resting stage. ([Highlight](https://www.frontiersin.org/journals/ecology-and-evolution/articles/10.3389/fevo.2019.00164/full#:~:text=Even%20unicellulars%20can%20evaluate%20the%20situation%20within%20the%20cell%20and%20in%20the%20surroundings%20and%20make%20decisions%20about%20pursuing%20resources%2C%20closing%20enemies%20out%2C%20dividing%2C%20or%20entering%20a%20resting%20stage%20(V%C3%A5ge%20et%20al.%2C%202014%3B%20Lyon%2C%202015%3B%20Bi%20and%20Sourjik%2C%202018)))

Is it irrational to believe that maybe our decision making has evolved over time to be exceptionally fast and accurate at calculating what would benefit us, “selfishly”? Selfish, as in doing something because it makes you feel better, or it makes you feel more socially acceptable, or you do it because you want to, or it provides dopamine and it's stimulating, or you only do it because it's the better of the worse choices.

So let me present some hypotheticals.

Hypothetical: Being forced to do something under coercion, you agree to do it, are you really acting in selfish interest?

Yes, because say the police have forced me to go to prison for the rest of my life or I can kill myself. Coercion, or alternative. How do I choose? Well, prison sucks but it's not the end of the world. There are many things to do, they have a library and computers, I can still enjoy life to some degree and maybe there's a chance for parole. Or, I kill myself and it's all over. Now I have to decide what's more ideal, well maybe I'll give prison a try for a while and see how it goes before I kill myself. Why did I choose that? Because I want to live, ideally, so it's a decision made in my personal interest to potentially remain alive and still enjoy the things life has to offer like warm food and comfort, and attempting suicide has a risk of remaining alive but a vegetable, which I don't want to be. Decision made in my own interest.

Hypothetical: Pregnant woman smoking a cigarette. Did she decide to smoke the cigarette out of her own interest, or is it only because she is addicted and unable to stop?

She decided to smoke the cigarette because of the stress relief, dopamine, and minor euphoria she has become dependent on to enjoy life. She looks forward to each cigarette because it's a comforting vice. She knows smoking while pregnant is a bad idea, but in this moment, she thinks it's okay to smoke one more cigarette and she plans to stop someday soon. So the decision was made out of her own interest in the euphoria rather than because she's forced to act out of addiction.

Hypothetical: Are mundane decisions and actions also chosen out of personal interest? What about deciding where to place your foot in each step, or choosing the next word to come out of your mouth, or when you decide to go to sleep?

All actions are made in your interest. You choose the best place for your foot because you don't want to break it, or get hurt, because that's an unpleasant experience. You choose your words based on what you know about English, and you want to be well understood and you want to talk like the person you're communicating with so they will like you more, and relate to you more, because that provides you with a feeling of social acceptance, bond, or companionship, which derives from evolutionary social survival pressures. You decide to go to sleep when the relief of sleep outweighs the experience of remaining awake, essentially your body makes remaining awake more and more unbearable to the degree of complete and total physiological suffering, to encourage you to decide by your own self interest to end the unpleasant experience and feel comfort again.

Hypothetical: Can someone make decisions they believe are NOT in their own interests, for example punching yourself suddenly for no reason (“to test my theory” sounds fun but this implies there's actually purpose so we won't include that).

You punch yourself very hard in the face for no reason at all. What compelled you to make this decision? If it was truly unexpected, then you didn't make the decision, so it wasn't anything you had some conscious or subconscious control over. Or if you truly did intend to hit yourself but for no reason at all, then you already knew the outcome in advance, hitting yourself, so it was an acceptable outcome and you made that decision. A decision cannot be unacceptable (the agent is uncompliant), and acted upon willingly, as that would be contradictory.

In a way, it's impossible to make a decision without doing a cost-benefit analysis at least subconsciously, and deciding that you accept the outcome. If it were possible to decide to do anything without some underlying logic, then the average animal would probably look a lot more retarded.

What would be the case for illogical decision making, from the perspective of the decision-maker, in evolution? In my mind, there can't be one. Evolution has determined since unicellular organisms that we act depending upon our needs and the environment, weighing risks and variables if the size of the brain or processor permits. All animals acting irrationally would not have survived very long, running directly into the mouth of a tiger, or throwing themselves from cliffsides.

Arguably, many animals do throw themselves from cliffsides, but they likely don't understand the consequences. They don't need to understand the consequences to make the decision. When the decision is made, the brain believes it is the next best choice, regardless of whatever logic got them there.
